import 'package:get/get.dart';
import 'package:mypoint_flutter_app/networking/restful_api_request.dart';
import '../../../base/restful_api_viewmodel.dart';
import '../models/product_model.dart';
import '../models/product_store_model.dart';

class VoucherDetailViewModel extends RestfulApiViewModel {
  final int productId;
  VoucherDetailViewModel({required this.productId});
  var stores =  RxList<ProductStoreModel>();
  var product = Rxn<ProductModel>();
  var isLoading = false.obs;
  var liked = false.obs;

  @override
  void onInit() {
    super.onInit();
    _getProductDetail();
    _getProductStores();
  }

  Future<void> toggleFavorite() async {
    // if (liked.value) {
    //    liked.value = false;
    // } else {
    //    liked.value = true;
    // }
    final value = product.value;
    if (value == null) return;
    if (value!.liked == true) {
      await client.unlikeProduct(value?.likeId ?? 0);
      value?.likeId = 0;
      Future.microtask(() => liked.value = false);
    } else {
      final response = await client.likeProduct(productId);
      value?.likeId = response.data?.id;
      Future.microtask(() => liked.value = (response.data?.id ?? 0) != 0);
    }
    // product.refresh();
  }

  Future<void> _getProductDetail() async {
    if (isLoading.value) return;
    try {
      isLoading.value = true;
      final response = await client.getProduct(productId);
      product.value = response.data;
      liked.value = product.value?.liked == true;
    } catch (error) {
      print("Error fetching product detail: $error");
    } finally {
      isLoading.value = false;
    }
  }

  Future<void> _getProductStores() async {
    try {
      final response = await client.getProductStores(productId);
      stores.value = response.data ?? [];
    } catch (error) {
      print("Error fetching product detail: $error");
    } finally {
    }
  }
}
